from typing import Dict, List, Optional

import typer

from casename.candidates import make_candidates
from casename.partify import itemize_parties

app = typer.Typer()


@app.command()
def make_case_names(
    source_text: str,
    footnote_index: Optional[int] = None,
) -> Optional[List[Dict]]:
    """
    If footnote_index exists, text is a footnote value; otherwise it's a paragraph segment of the decision
    Get candidates, split into parties, clean. Results in dictionary:
    1. The raw text, if found in the footnote section;
    2. The cleaned plaintiff and the cleaned defendant
    3. The citation, if possible
    4. The value of the footnote key in case the text is found in footnotes section
    """
    if not (candidates := make_candidates(source_text, footnote_index)):
        return None
    return list(itemize_parties(candidates)) or candidates


def main():
    text = typer.prompt("What text?")
    results = make_case_names(text)
    print(results)


if __name__ == "__main__":
    typer.run(main)
