from typing import Dict, Iterator, List, Optional

from .defendant import defendant
from .plaintiff import plaintiff
from .split import cullcite
from .utils import (
    RE_PATTERN,
    VS_PATTERN,
    is_single_simple_versus,
    is_two_parties_between_versus,
)


def itemize_parties(candidates: List[Dict]) -> Iterator[Dict]:
    for c in candidates:
        # valid casename required to create parties
        if not c["casename"]:
            continue

        # if can create an in re case from candidate, yield
        if (inre := RE_PATTERN.search(c["casename"])) :
            text_string = c["casename"]
            removed_inre_prefix = text_string[inre.end() :]
            c["inre"] = removed_inre_prefix.strip()
            yield c
            continue

        # split into two:
        if len(parties := VS_PATTERN.split(c["casename"])) == 2:
            if (error := red_flag(c["casename"], *parties)) :
                c["error"] = error
                yield c
                continue

            # get parties
            c["plaintiff"], c["defendant"] = (*parties,)

            # check if no existing citation, possibility in defendant
            if not c["citation"]:
                c["defendant"], c["citation"] = cullcite(c["defendant"])

            # if existing citation found in defendant, clean defendant
            elif c["citation"] in c["defendant"]:
                c["defendant"] = c["defendant"].replace(c["citation"], "")

            yield c | (
                {
                    "casename": c["casename"].strip(";, "),
                    "defendant": defendant(c["defendant"]),
                    "plaintiff": plaintiff(c["plaintiff"]),
                }
            )


def red_flag(c: str, plaintiff: str, defendant: str) -> Optional[str]:
    text = None
    if not is_single_simple_versus(c):
        text = f"More than one vs. / re string: {c}"
    if not is_two_parties_between_versus(c):
        text = f"More than two parties in vs. string: {c}"
    if len(plaintiff) > 120:
        text = f"Plaintiff string too long: {plaintiff}"
    if len(defendant) > 120:
        text = f"Defendant string too long: {defendant}"
    return text
