from .party import (
    missing_brackets,
    remove_case_of,
    remove_cf,
    remove_citing,
    remove_eg,
    remove_etal,
    remove_etc,
    remove_in,
    remove_prefixes,
    uniform_replacements,
)


def plaintiff(text: str) -> str:
    """
    Deals with cases where a plaintiff includes other words preceded by signals
    e.g. "Court ruled in Interpacific Transit, Inc." --> signal is "in"
    e.g. "the recent case of Lozon v. NLRC" --> signal is "case of"
    e.g. "Cf. People vs. Magpale,"
    e.g. "citing National Brewery and Allied Industries Labor Union of the Philippines v. San Miguel Brewery, Inc.,"
    e.g. "see Butuan City vs. Ortiz, et. al.,"
    Note the positive lookahead means that this will be used in determining a match
    but will not be captured in the match itself
    """
    text = text.strip()

    # must remove et al before reaching etc.
    text = remove_etal(text)

    # must remove etc before reaching meat.
    text = remove_etc(text)

    # usually immediate
    text = text.rstrip(":,”' ")

    # deal with missing brackets
    text = missing_brackets(text)

    # plaintiff-specific cleaning on left side of vs. phrase
    text = remove_in(text)
    text = remove_prefixes(text)
    text = remove_case_of(text)
    text = remove_cf(text)
    text = remove_citing(text)
    text = remove_eg(text)
    text = text.lstrip(".,( ")

    # make replacements
    text = uniform_replacements(text)

    return text
